@@ -103,14 +103,31 @@ char *argv[];
 	}
 	ef_close(EF_NATION);
 	comminit(make(commfil));
+	if (access(teldir, F_OK) < 0 && mkdir(teldir, 0750) < 0) {
+		perror(teldir);
+		printf("Can't make telegram directory\n");
+		exit(1);
+	}
 	for (x = MAXNOC - 1; x >= 0; x--) {
 		filename = mailbox(buf, x);
 		close(creat(filename, 0600));
 		chmod(filename, 0600);
 	}
+	if (access(syncdir, F_OK) < 0 && mkdir(syncdir, 0750) < 0) {
+		perror(syncdir);
+		printf("Can't make sync directory\n");
+		exit(1);
+	}
+	for (x = MAXNOC - 1; x >= 0; x--) {
+		filename = syncbox(buf, x);
+		close(creat(filename, 0600));
+		chmod(filename, 0600);
+	}
 	close(creat(annfil, 0600));
 	chmod(infodir, 0750);
 	chmod(datadir, 0770);
+	chmod(teldir, 0770);
+	chmod(syncdir, 0770);
 
 	/* create a zero-filled sector file */
 	bzero(&sct,sizeof(sct));
