@@ -32,7 +32,7 @@ struct	lndstr {
 	coord	lnd_opx,lnd_opy;/* Op sector coords */
 	short	lnd_mission;	/* mission code */
 	short	lnd_radius;	/* mission radius */
-	s_char	lnd_spare;	/* extra space */
+	s_char	lnd_flags;	/* unit flags */
 	short	lnd_ship;	/* pointer to transporting ship */
         s_char	lnd_harden;	/* for missiles */
         short	lnd_retreat;	/* retreat percentage */
@@ -47,6 +47,8 @@ struct	lndstr {
 	u_short	lnd_vamt[MAXLNDV];
 };
 
+#define LND_NOSYNC bit(0)
+
 struct	lchrstr {
 	u_char	l_nv;		/* number of variables it can hold */
 	u_char	l_vtype[MAXCHRNV];
