@@ -483,7 +483,7 @@ build_land(sp, lp, vec, tlev)
 	land.lnd_tech = tlev;
 	land.lnd_uid = nstr.cur;
 	land.lnd_army = ' ';
-	land.lnd_spare = 0;
+	land.lnd_flags = 0;
 	land.lnd_ship = -1;
 	land.lnd_harden = 0;
 	land.lnd_retreat = 75 - (int)natp->nat_level[NAT_HLEV];
