@@ -35,16 +35,18 @@ sync()
 		return RET_SYN;
 	
 	switch (*player->argp[1]) {
+	case 'o':
+		return sync_object();
+	case 'c':
+		return sync_class();
+	case 'r':
+		return sync_catchup();
 	case 'v':
 		return sync_version();
 	case 's':
 		return sync_checksum();
 	case 'd':
 		return sync_define();
-	case 'o':
-		return sync_object();
-	case 'c':
-		return sync_class();
 	default:
 		return RET_SYN;
 	}
@@ -205,6 +207,7 @@ sync_object()
 		natp = getnatp(player->cnum);
 		xyrelrange(natp, &ns.range, &range);
 		map.ef_type = EF_MAP;
+		map.map_own = player->cnum;
 		map.map_leftx = ns.x;
 		map.map_y = ns.y;
 		i = 0;
@@ -310,3 +313,41 @@ squeeze_map(mp)
 	}
 }
 
+sync_catchup()
+{
+	struct	natstr	*natp = getnatp(player->cnum);
+	s_char	buf[4096];
+	FILE	*fp;
+	s_char	*p = "Can I throw this information away now? ";
+	s_char	filename[512];
+
+	if (!natp->nat_synctim)
+		return;
+
+	syncbox(filename, player->cnum);
+	if (!(fp = fopen(filename, "r"))) {
+		logerror("Read failed: %s", filename);
+		return;
+	}
+	while (fgets(buf, 4096, fp))
+		pr_sync(buf);
+
+	p = getstarg(player->argp[2], p, buf);
+	if (p && *p == 'y') {
+		natp->nat_synctim = 0;
+		putnat(natp);
+#ifdef sys5
+		/* I don't have ftruncate, so here's my stand in */
+		FILE *holdf;
+		holdf = fopen(filename, "w+"); /* I hope this kills */
+		rewind(fp);
+		fclose(holdf);
+	}
+#else
+		ftruncate(fileno(fp), 0);
+	}
+#endif /* sys5 */
+
+	fclose(fp);
+
+}
