@@ -116,7 +116,6 @@ extern	int rela();
 extern	int brea();
 extern	int upda();
 extern	int hidd();
-extern	int bdes();
 extern	int orde();
 extern	int qorde();
 extern  int sorde(); 
@@ -201,7 +200,6 @@ struct  comstr  player_coms[]  = {
 "army <ARMY> <UNITS>",                  0,	army,	C_MOD, NORM,
 "assault <to-SECT> <from-SHIP> [<forts?> <ships?> <arty?> <planes?>]",3,assa,C_MOD, NORM+MONEY+CAP,
 "attack <SECT> [<forts?> <ships?> <arty?> <planes?>]",3,atta,C_MOD, NORM+MONEY+CAP,
-"bdes <SECTS> <type>",                  0,	bdes,	C_MOD, NORM,
 "bestpath <SECTS> <SECTS>",             0,	best,	0, NORM,
 "bestdistpath <SECTS> <SECTS>",         0,	best,	0, NORM,
 "bmap <SECTS|UNIT> [s|l|p|*]",                         0,	map,	0, NORM,
@@ -354,7 +352,7 @@ struct  comstr  player_coms[]  = {
 "strength <SECTS>", 			1,	stre,	C_MOD, NORM,
 "supply <LAND UNITS>",                  1,	supp,	C_MOD, NORM+CAP,
 "survey <COMM|VAR> <SECTS>",            0,	surv,	0, NORM+CAP,
-"sync [version|checksum|define|object <type> <which>|class <type> <which>", 0, sync, 0, VIS,
+"sync [version|sum|read|define|object <type> <which>|class <type> <which>", 0, sync, 0, VIS,
 "swapsector <SECT> <SECT>", 		0,	swaps,	C_MOD, GOD,
 "sweep <sweep-PLANES> <fighter-PLANES> <ap-SECT> <PATH|DESTINATION>",3,reco,C_MOD, NORM+MONEY+CAP,
 "telegram <NAT>",                       0,	tele,	C_MOD, NORM,
