@@ -86,8 +86,14 @@ player_main(p)
 	}
 	if (*player->userid)
 		strcpy(natp->nat_userid, player->userid);
+	else
+		strcpy(natp->nat_userid, "nobody");
+
 	if (*player->hostname)
 		strcpy(natp->nat_hostname, player->hostname);
+	else
+		strcpy(natp->nat_hostname, "nowhere");
+
 	if (*player->hostaddr)
 		strcpy(natp->nat_hostaddr, player->hostaddr);
 	
