@@ -94,17 +94,18 @@ typed_wu(from, to, message, type)
 		strcpy(box, annfil);
 	else
 		mailbox(box, to);
-	if ((fd = open(box, O_WRONLY|O_APPEND, 0)) < 0) {
-		logerror("telegram 'open' of %s (#%d) failed", box, to);
-		return -1;
-	}
+
 	if (type != TEL_ANNOUNCE)
 		if ((np = getnatp(to)) == 0 ||
 		    ((np->nat_stat & STAT_NORM) == 0 &&
 		     (np->nat_stat & STAT_SANCT) == 0)) {
-			close(fd);
 			return -1;
 		}
+
+	if ((fd = open(box, O_WRONLY|O_APPEND, 0)) < 0) {
+		logerror("telegram 'open' of %s (#%d) failed", box, to);
+		return -1;
+	}
 	tel.tel_from = from;
 	(void) time(&tel.tel_date);
 	bp = message;
@@ -124,8 +125,8 @@ typed_wu(from, to, message, type)
 		logerror("telegram 'write' to #%d failed", to);
 	} else if (type == TEL_ANNOUNCE) {
 		for (to=0; np = getnatp(to); to++) {
-			if (((np->nat_stat & STAT_NORM) == 0) &&
-			    ((np->nat_stat & STAT_SANCT) == 0))
+			if (!(np->nat_stat & STAT_NORM) &&
+			    !(np->nat_stat & STAT_SANCT))
 				continue;
 			if (!player->god && (getrejects(from,np) & REJ_ANNO))
 				continue;
