@@ -46,7 +46,8 @@ struct	natstr {
 	time_t	nat_last_login;		/* time of last login */
 	time_t	nat_last_logout;	/* time of last logout */
 	time_t	nat_newstim;		/* date news last read */
-	time_t	nat_annotim;		/* date annos last read (not used) */
+	time_t	nat_annotim;		/* date annos last read */
+	time_t	nat_synctim;		/* date syncspool last read */
 	float	nat_level[4];		/* technology, etc */
 	struct	boundstr nat_b[MAXNOR];	/* realm bounds */
 	short	nat_relate[MAXNOC];
